'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.resolveProps = resolveProps;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _getBrowserInformation = require('./getBrowserInformation');

var _getBrowserInformation2 = _interopRequireDefault(_getBrowserInformation);

var _caniuseData = require('./caniuseData');

var _caniuseData2 = _interopRequireDefault(_caniuseData);

var _Plugins = require('./Plugins');

var _Plugins2 = _interopRequireDefault(_Plugins);

var browserinfo = undefined;
var browserProps = undefined;
var lastUserAgent = undefined;

var defaultUserAgent = typeof navigator !== 'undefined' ? navigator.userAgent : undefined;

/**
 * Processes an object of styles using userAgent specific
 * @param {Object} styles - Styles object that gets prefixed
 * @param {string} userAgent - userAgent to gather prefix information according to caniuse.com
 */

exports['default'] = function (styles) {
  var userAgent = arguments.length <= 1 || arguments[1] === undefined ? defaultUserAgent : arguments[1];

  if (userAgent && lastUserAgent !== userAgent) {
    var _ret = (function () {
      browserinfo = (0, _getBrowserInformation2['default'])(userAgent);
      var data = _caniuseData2['default'][browserinfo.browser];
      if (data) {
        browserProps = Object.keys(data).filter(function (key) {
          return data[key] >= browserinfo.version;
        });
      } else {
        console.warn('Your userAgent seems to be not supported by inline-style-prefixer. Feel free to open an issue.');
        return {
          v: styles
        };
      }
    })();

    if (typeof _ret === 'object') return _ret.v;
  }
  //only add prefixes if needed
  if (browserProps && browserProps.length > 0) {
    resolveProps(styles);
  }
  return styles;
};

/**
 * Capitalizes first letter of a string
 * @param {String} str - str to caplitalize
 */
var caplitalizeString = function caplitalizeString(str) {
  return str.charAt(0).toUpperCase() + str.slice(1);
};

/**
 * Adds prefixed properties to a style object
 * @param {Object} styles - Style object that gets prefixed properties added
 */

function resolveProps(styles) {
  Object.keys(styles).forEach(function (property) {
    var value = styles[property];
    if (value instanceof Object) {
      //recursively loop through nested style objects
      resolveProps(value);
    } else {
      //add prefixes if needed
      if (browserProps.indexOf(property) > -1) {
        styles[browserinfo.prefix.inline + caplitalizeString(property)] = value;
        delete styles[property];
      }
      //resolve plugins
      _Plugins2['default'].forEach(function (plugin) {
        return (0, _objectAssign2['default'])(styles, plugin(property, value, browserinfo, styles));
      });
    }
  });
  return styles;
}